@@ -2,7 +2,8 @@
 #define DENON_H
 
 #include "pirkeysetmetadata.h"
-#include <QObject>
+
+class QObject;
 
 class DenonDVD1: public PIRKeysetMetaData
 {
