@@ -3,7 +3,7 @@
 
 #include "pirkeysetmetadata.h"
 
-#include <QObject>
+class QObject;
 
 class SanyoVCR1: public PIRKeysetMetaData
 {
@@ -45,7 +45,7 @@ public:
     unsigned int index);
 };
 
-class SanyoTV1c: public SanyoTV1
+class SanyoTV1c: public SanyoTV1a
 {
 public:
   SanyoTV1c(
@@ -53,7 +53,7 @@ public:
     unsigned int index);
 };
 
-class SanyoTV1d: public SanyoTV1a
+class SanyoTV1d: public SanyoTV1
 {
 public:
   SanyoTV1d(
@@ -61,14 +61,6 @@ public:
     unsigned int index);
 };
 
-class SanyoTV1e: public SanyoTV1
-{
-public:
-  SanyoTV1e(
-    QObject *guiObject,
-    unsigned int index);
-};
-
 class SanyoProjector: public PIRKeysetMetaData
 {
 public:
