@@ -7,33 +7,40 @@ class QComboBox;
 enum PIRMakeName{
   Any_Make,
   Acer_Make,
+  Admiral_Make,
   Aiwa_Make,
   Apple_Make,
   Bose_Make,
+  Daewoo_Make,
   Denon_Make,
   Ei_Make,
   Elgato_Make,
   GoldStar_Make,
+  Grundig_Make,
   Hauppauge_Make,
   Hitachi_Make,
   JVC_Make,
   LG_Make,
+  Logitech_Make,
   Magnavox_Make,
   Microsoft_Make,
   Mitsubishi_Make,
   Nokia_Make,
   Panasonic_Make,
+  Philco_Make,
   Philips_Make,
   Pinnacle_Make,
   Pioneer_Make,
   Raite_Make,
   RCA_Make,
+  Roku_Make,
   Sagem_Make,
   Samsung_Make,
   Sanyo_Make,
   Sharp_Make,
   Sony_Make,
   Tivo_Make,
+  Topfield_Make,
   Toshiba_Make,
   Westinghouse_Make,
   Yamaha_Make,
